cmd

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 2, 2026 License: MIT Imports: 21 Imported by: 0

Documentation

Overview

Package cmd provides the root Cobra command and command tree for ytr CLI.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddCommand

func AddCommand(cmds ...*cobra.Command)

AddCommand registers subcommands on the root command. This allows subcommand packages to register themselves without accessing rootCmd directly.

func Execute

func Execute() int

Execute runs the root command and returns the appropriate exit code. The caller (main.go) must pass this to os.Exit.

func RootCmd

func RootCmd() *cobra.Command

RootCmd returns the root command for testing purposes.

Types

This section is empty.

Directories

Path Synopsis
Package auth provides authentication commands for the ytr CLI.
Package auth provides authentication commands for the ytr CLI.
Package bulk provides bulk change commands for the ytr CLI.
Package bulk provides bulk change commands for the ytr CLI.
Package checklist provides checklist management commands for the ytr CLI.
Package checklist provides checklist management commands for the ytr CLI.
Package comment provides comment management commands for the ytr CLI.
Package comment provides comment management commands for the ytr CLI.
Package completion provides shell completion script generation for ytr.
Package completion provides shell completion script generation for ytr.
Package component provides component management commands for the ytr CLI.
Package component provides component management commands for the ytr CLI.
Package field provides field discovery commands for the ytr CLI.
Package field provides field discovery commands for the ytr CLI.
Package issue provides issue management commands for the ytr CLI.
Package issue provides issue management commands for the ytr CLI.
Package issuetype provides issue type commands for the ytr CLI.
Package issuetype provides issue type commands for the ytr CLI.
Package jsonfields provides a registry for JSON field completions.
Package jsonfields provides a registry for JSON field completions.
Package link provides link management commands for the ytr CLI.
Package link provides link management commands for the ytr CLI.
Package priority provides priority commands for the ytr CLI.
Package priority provides priority commands for the ytr CLI.
Package queue provides queue management commands for the ytr CLI.
Package queue provides queue management commands for the ytr CLI.
Package resolution provides resolution commands for the ytr CLI.
Package resolution provides resolution commands for the ytr CLI.
Package status provides status commands for the ytr CLI.
Package status provides status commands for the ytr CLI.
Package user provides user management commands for the ytr CLI.
Package user provides user management commands for the ytr CLI.
Package version provides the ytr version command.
Package version provides the ytr version command.
Package worklog provides worklog management commands for the ytr CLI.
Package worklog provides worklog management commands for the ytr CLI.

Jump to