auth

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 2, 2026 License: MIT Imports: 14 Imported by: 0

Documentation

Overview

Package auth provides authentication commands for the ytr CLI. It includes login, status, and logout subcommands under "ytr auth".

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewCmd

func NewCmd() *cobra.Command

NewCmd creates the parent "auth" command with login, status, and logout subcommands. Running "ytr auth" alone displays help.

Types

This section is empty.

Jump to